@@ -7,18 +7,20 @@ class TestFeh:
         assert completion
 
     @pytest.mark.complete(
-        "feh --lis", skipif="feh --help 2>&1 | grep -qF 'man feh'"
+        "feh --lis",
+        xfail="feh --help 2>&1 | command grep -qF 'man feh'",
+        require_cmd=True,
     )
     def test_2(self, completion):
         assert completion
 
     @pytest.mark.complete("feh -S pix")
     def test_3(self, completion):
-        assert completion == "pixels"
+        assert completion == "els"
 
     @pytest.mark.complete("feh --zoom ma")
     def test_4(self, completion):
-        assert completion == "max"
+        assert completion == "x"
 
     @pytest.mark.complete("feh -g 640")
     def test_5(self, completion):
