@@ -6,6 +6,6 @@ class TestGroupmod:
     def test_1(self, completion):
         assert completion
 
-    @pytest.mark.complete("groupmod -")
+    @pytest.mark.complete("groupmod -", require_cmd=True)
     def test_2(self, completion):
         assert completion
