@@ -6,6 +6,6 @@ class TestIrb:
     def test_1(self, completion):
         assert completion
 
-    @pytest.mark.complete("irb -", require_cmd=True)
+    @pytest.mark.complete("irb -", require_longopt=True)
     def test_options(self, completion):
         assert completion
