@@ -6,6 +6,6 @@ class TestIsort:
     def test_1(self, completion):
         assert completion
 
-    @pytest.mark.complete("isort -", require_cmd=True)
+    @pytest.mark.complete("isort -", require_longopt=True)
     def test_2(self, completion):
         assert completion
