@@ -6,8 +6,6 @@ class TestJsonschema:
     def test_1(self, completion):
         assert completion
 
-    @pytest.mark.complete(
-        "jsonschema -", require_cmd=True, require_longopt=True
-    )
+    @pytest.mark.complete("jsonschema -", require_longopt=True)
     def test_2(self, completion):
         assert completion
