@@ -4,14 +4,14 @@ import pytest
 
 
 class TestModinfo:
-    @pytest.mark.complete("modinfo -")
+    @pytest.mark.complete("modinfo -", require_cmd=True)
     def test_1(self, completion):
         assert completion
 
-    # "in": intel*, ...
+    # "du": dummy, ...
     @pytest.mark.complete(
-        "modinfo in",
-        skipif="! ls /lib/modules/%s &>/dev/null"
+        "modinfo du",
+        xfail="! ls /lib/modules/%s &>/dev/null"
         % subprocess.check_output(
             "uname -r 2>/dev/null || " "echo non-existent-kernel", shell=True
         )
@@ -21,8 +21,8 @@ class TestModinfo:
     def test_2(self, completion):
         assert completion
 
-    # "in": intel*, ...
-    @pytest.mark.complete("modinfo -k non-existent-kernel in")
+    # "du": dummy, ...
+    @pytest.mark.complete("modinfo -k non-existent-kernel du")
     def test_3(self, completion):
         assert not completion
 
