@@ -6,6 +6,6 @@ class TestPr:
     def test_1(self, completion):
         assert completion
 
-    @pytest.mark.complete("pr -", require_cmd=True)
+    @pytest.mark.complete("pr -", require_longopt=True)
     def test_options(self, completion):
         assert completion
