@@ -2,6 +2,6 @@ import pytest
 
 
 class TestQuerybts:
-    @pytest.mark.complete("querybts --")
+    @pytest.mark.complete("querybts --", require_cmd=True)
     def test_1(self, completion):
         assert completion
