@@ -2,6 +2,6 @@ import pytest
 
 
 class TestSed:
-    @pytest.mark.complete("sed --", skipif="! sed --help &>/dev/null")
+    @pytest.mark.complete("sed --", require_longopt=True)
     def test_1(self, completion):
         assert completion
