@@ -1,7 +1,7 @@
 import pytest
 
 
-@pytest.mark.bashcomp(ignore_env=r"^[+-]_scp_path_esc=")
+@pytest.mark.bashcomp(ignore_env=r"^[+-]_comp_cmd_scp__path_esc=")
 class TestSshfs:
     @pytest.mark.complete("sshfs ./")
     def test_1(self, completion):
