@@ -1,7 +1,9 @@
 import pytest
 
 
-@pytest.mark.bashcomp(ignore_env=r"^-declare -f _vncviewer_bootstrap$")
+@pytest.mark.bashcomp(
+    ignore_env=r"^-declare -f _comp_cmd_vncviewer__bootstrap$"
+)
 class TestVncviewer:
     @pytest.mark.complete("vncviewer ")
     def test_1(self, completion):
