@@ -6,7 +6,7 @@ class TestXgamma:
     def test_1(self, completion):
         assert completion
 
-    @pytest.mark.complete("xgamma -gam", require_cmd=True)
+    @pytest.mark.complete("xgamma -gamm", require_cmd=True)
     def test_2(self, completion):
-        assert completion == "-gamma"
+        assert completion == "a"
         assert completion.endswith(" ")
